#!/bin/bash

################################################################################
# Title:        Bldhelper.sh
# Description:  Script to build peppermint openbox ISO image
# Author:       manuel rosa <manuelsilvarosa@gmail.com>
# Date:         Outubro 29, 2023
# License:      GPL-3.0-or-later
################################################################################

# Set environment variables
PREFIX=PeppermintOS-deb-openbox
SUFFIX=arm64
BUILD=pep-openbox-arm64
TODAY=$(date -u +"%Y-%m-%d")
FileName="${PREFIX}-${SUFFIX}"
LOCATION="/home/$SUDO_USER/out/${BUILD}"
LogDir="/home/$SUDO_USER/logs"
WorkingDir="/home/$SUDO_USER/MRTestRepo/debian-arm64"


# Execute the ISO building script
cd ${WorkingDir}
./build.sh 2>&1 | tee /tmp/build_log.txt

# Move and rename the ISO file
cd fusato
mv *.iso ${FileName}-${TODAY}.iso

# Create the checksum file for the ISO
sha512sum ${FileName}-${TODAY}.iso > ${FileName}-${TODAY}-sha512.checksum

# Remove old ISO and checksum files from the desired location
rm -f ${LOCATION}/${FileName}*.iso
rm -f ${LOCATION}/${FileName}*-sha512.checksum

# Move the ISO and checksum files to the desired location
mkdir -p ${LOCATION}
mv ${FileName}-${TODAY}.iso ${LOCATION}
mv ${FileName}-${TODAY}-sha512.checksum ${LOCATION}

# Move the log file to the log directory (if it exists)
if [ -f /tmp/build_log.txt ]; then
    LogFileName="${PREFIX}-${SUFFIX}-${BUILD}.log"
    mv /tmp/build_log.txt ${LogDir}/${LogFileName}
fi
# Clean the build folder 
lb clean

# Remove the "build" directory and its contents
cd ..
rm -rf fusato

